@@ -3,20 +3,20 @@
 
 // malloc with NULL check
 void *
-t_malloc(size_t size);
-
-// free with NULL check
-void
-t_free(void *p);
+xmalloc(size_t size);
 
 // realloc with NULL check
 void *
-t_realloc(void *p, size_t size);
+xrealloc(void *p, size_t size);
 
 // Convert a string to upper case
 char *
 uppercase(char *str);
 
+// Check whether str ends with suffix
+bool
+endswith(const char *str, const char *suffix);
+
 // Get human readable signal string
 int
 get_sig_name(int sig, char *buf);
@@ -25,6 +25,14 @@ get_sig_name(int sig, char *buf);
 int
 get_sig(const char *sig_name);
 
+// print signal list
+void
+print_sig_list();
+
+// Open uri with the default application of system
+int
+open_uri(char *uri);
+
 // Encode text to base64, the caller should free the returned string
 char *
 base64_encode(const unsigned char *buffer, size_t length);
